#include <chrono>
#include <iostream>
#include <string>

#include "tsdb.h"

int main() {
    // 连接到时序数据库服务 (位于 localhost)
    tsdb_cpp::tsdb_entry db("localhost", 9000);
    // tsdb_cpp::tsdb_entry db("172.31.48.206", 8123);

    // 选中数据表 (默认为 tsdb_cpp_dist)
    db.set_active_table("tsdb_cpp");

    // 插入单个点，名字为 name1，数据为 1.3，时间为 UTC 100001 纳秒
    db.insert_point("name1", 1.3, 100001);

    db.insert_points({{"name1", 1.3, 100001}});

    // 批量插入点数据
    auto t1 = std::chrono::high_resolution_clock::now();
    {
        auto batch          = db.new_batch_insert();
        std::string pt_name = "many_points";
        for (int i = 0; i < 1000000; i++) {
            batch.add_point(pt_name, 4.2, i + 1000000);
            // db.insert_point(pt_name, 4.2, i + 1000000);
        }
        // 批量插入点
        batch.close();
    }
    auto t2 = std::chrono::high_resolution_clock::now();
    std::cout << "Batch insert time: " << std::chrono::duration_cast<std::chrono::milliseconds>(t2 - t1).count() << " ms" << std::endl;

    std::cout << "All success!" << std::endl;
}
